@@ -4,13 +4,11 @@ use 5.010;
 use strict;
 use warnings;
 
-use YAML::Syck;
-
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(format_pretty);
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 sub content_type { "text/yaml" }
 
@@ -18,10 +16,17 @@ sub format_pretty {
     my ($data, $opts) = @_;
     $opts //= {};
 
-    local $YAML::Syck::ImplicitTyping = 1;
-    local $YAML::Syck::SortKeys       = 1;
-    local $YAML::Syck::Headless       = 1;
-    Dump($data);
+    if ($opts->{color} // (-t STDOUT)) {
+        require YAML::Tiny::Color;
+        local $YAML::Tiny::Color::LineNumber = 1;
+        YAML::Tiny::Color::Dump($data);
+    } else {
+        require YAML::Syck;
+        local $YAML::Syck::ImplicitTyping = 1;
+        local $YAML::Syck::SortKeys       = 1;
+        local $YAML::Syck::Headless       = 1;
+        YAML::Syck::Dump($data);
+    }
 }
 
 1;
@@ -36,7 +41,7 @@ Data::Format::Pretty::YAML - Pretty-print data structure as YAML
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -69,6 +74,21 @@ YAML::Syck's settings are optimized for prettiness, currently as follows:
  $YAML::Syck::SortKeys       = 1;
  $YAML::Syck::Headless       = 1;
 
+Options:
+
+=over
+
+=item * color => BOOL
+
+Whether to enable coloring. The default is the enable only when running
+interactively. Currently also enable line numbering.
+
+=back
+
+=head2 content_type() => STR
+
+Return C<text/yaml>.
+
 =head1 SEE ALSO
 
 L<Data::Format::Pretty>
